@@ -6,7 +6,7 @@ Toadfarm - One Mojolicious app to rule them all
 
 =head1 VERSION
 
-0.59
+0.60
 
 =head1 DESCRIPTION
 
@@ -159,7 +159,7 @@ use File::Spec;
 use File::Which;
 use constant DEBUG => $ENV{TOADFARM_DEBUG} ? 1 : 0;
 
-our $VERSION = '0.59';
+our $VERSION = '0.60';
 
 BEGIN {
   $ENV{TOADFARM_ACTION} //= (@ARGV and $ARGV[0] =~ /^(reload|start|stop)$/) ? $1 : 'load';
@@ -382,7 +382,7 @@ sub _setup_app {
   my ($class, $app, $got) = @_;
   my $config = $app->config;
 
-  $app->secrets([Mojo::Util::md5_sum(rand . time . $$ . $0)]) unless $got->{secrets};
+  $app->secrets([Mojo::Util::md5_sum($$ . $0 . time . rand)]) unless $got->{secrets};
   $app->_mount_apps(@{$config->{apps}})      if $config->{apps};
   $app->_load_plugins(@{$config->{plugins}}) if $config->{plugins};
 
